==> v0.4.10.zip: submit-social-housing-lettings-and-sales-data/spec/models/form/sales/questions/combined_income_value_check_spec.rb <==
require "rails_helper"

RSpec.describe Form::Sales::Questions::CombinedIncomeValueCheck, type: :model do
  subject(:question) { described_class.new(question_id, question_definition, page, check_answers_card_number: nil) }

  let(:question_id) { nil }
  let(:question_definition) { nil }
  let(:page) { instance_double(Form::Page) }

  it "has correct page" do
    expect(question.page).to eq(page)
  end

  it "has the correct id" do
    expect(question.id).to eq("combined_income_value_check")
  end

  it "has the correct header" do
    expect(question.header).to eq("Are you sure this is correct?")
  end

  it "has the correct check_answer_label" do
    expect(question.check_answer_label).to eq("Combined income confirmation")
  end

  it "has the correct type" do
    expect(question.type).to eq("interruption_screen")
  end

  it "is not marked as derived" do
    expect(question.derived?).to be false
  end

  it "has the correct hint" do
    expect(question.hint_text).to be_nil
  end

  it "has a correct check_answers_card_number" do
    expect(question.check_answers_card_number).to eq(nil)
  end

  it "has the correct answer_options" do
    expect(question.answer_options).to eq({
      "0" => { "value" => "Yes" },
      "1" => { "value" => "No" },
    })
  end

  it "has the correct hidden_in_check_answers" do
    expect(question.hidden_in_check_answers).to eq({
      "depends_on" => [
        {
          "combined_income_value_check" => 0,
        },
        {
          "combined_income_value_check" => 1,
        },
      ],
    })
  end
end

==> v0.4.42.zip: submit-social-housing-lettings-and-sales-data/spec/models/form/sales/questions/combined_income_value_check_spec.rb <==
require "rails_helper"

RSpec.describe Form::Sales::Questions::CombinedIncomeValueCheck, type: :model do
  subject(:question) { described_class.new(question_id, question_definition, page, check_answers_card_number: nil) }

  let(:question_id) { nil }
  let(:question_definition) { nil }
  let(:page) { instance_double(Form::Page) }

  it "has correct page" do
    expect(question.page).to eq(page)
  end

  it "has the correct id" do
    expect(question.id).to eq("combined_income_value_check")
  end

  it "has the correct header" do
    expect(question.header).to eq("Are you sure this is correct?")
  end

  it "has the correct check_answer_label" do
    expect(question.check_answer_label).to eq("Combined income confirmation")
  end

  it "has the correct type" do
    expect(question.type).to eq("interruption_screen")
  end

  it "is not marked as derived" do
    expect(question.derived?(nil)).to be false
  end

  it "has the correct hint" do
    expect(question.hint_text).to be_nil
  end

  it "has a correct check_answers_card_number" do
    expect(question.check_answers_card_number).to eq(nil)
  end

  it "has the correct answer_options" do
    expect(question.answer_options).to eq({
      "0" => { "value" => "Yes" },
      "1" => { "value" => "No" },
    })
  end

  it "has the correct hidden_in_check_answers" do
    expect(question.hidden_in_check_answers).to eq({
      "depends_on" => [
        {
          "combined_income_value_check" => 0,
        },
        {
          "combined_income_value_check" => 1,
        },
      ],
    })
  end
end
